@@ -20,6 +20,16 @@ from .continuous_monitoring_systems import AB_Continous_Monitoring_Systems
 from .continuous_monitoring_monitors import AB_Continous_Monitoring_Monitors
 from .continuous_monitoring_monitor_results import AB_Continous_Monitoring_Monitor_Results
 
+from .auditable_entity import AB_Auditable_Entities
+from .auditable_entity_regions import AB_Auditable_Entity_Regions
+from .auditable_entity_types import AB_Auditable_Entity_Types
+from .vendor_criticalities import AB_Vendor_Criticality
+
+from .buisness_units import AB_Business_Unit
+from .departments import AB_Departments
+
+from .multi import AB_Multi
+
 SUBOBJ_LK = {"region_id": {"obj": AB_Region},
              "process_id": {"obj": AB_Process},
              "subprocess_id": {"obj": AB_SubProcess},
@@ -30,7 +40,10 @@ SUBOBJ_LK = {"region_id": {"obj": AB_Region},
              "test_ids": {"obj": AB_Test},
              "file_ids": {"obj": AB_File},
              "continuous_monitoring_system_id": {"obj": AB_Continous_Monitoring_Systems},
-             "continuous_monitoring_monitor_id": {"obj": AB_Continous_Monitoring_Monitors}
+             "continuous_monitoring_monitor_id": {"obj": AB_Continous_Monitoring_Monitors},
+             "auditable_entity_id": {"obj": AB_Auditable_Entities},
+             "auditable_entity_region_id": {"obj": AB_Auditable_Entity_Regions},
+             "vendor_criticalities_id": {"obj": AB_Vendor_Criticality}
             }
 
 
