@@ -14,6 +14,11 @@ import abobjs
 
 
 class AB_Base:
+
+    '''
+    Base Object for API Calls
+    '''
+
     # People need to set these three
     _endpoint = None
     _single = None
@@ -86,7 +91,8 @@ class AB_Base:
             # I didn't get an ID
             if self.kwargs.get("uid", None) is not None or \
                     self.kwargs.get("search_name", None) is not None or \
-                    self.kwargs.get("search_complex", None) is not None:
+                    self.kwargs.get("search_complex", None) is not None or \
+                    self.kwargs.get("multi", False) is True:
 
                 # I searched for and found (or not) a result
                 try:
@@ -242,6 +248,12 @@ class AB_Base:
                     found_item = potential
                     break
 
+            elif self.kwargs.get("multi", False) is True:
+                # This is a multi request, we're going to use the results from kwargs["all_data"] So we just want
+                # to leave as soon as possible.
+                found_item = potential
+                break
+
             else:
                 # Continue to the Next Item to search for it.
                 pass
@@ -411,12 +423,23 @@ class AB_Base:
         :return:
         """
 
-        front, back = datestring.split(".")
+        this_date = None
 
-        this_ms = int("{}000".format(back.strip("Z")))
-        this_date = datetime.datetime.strptime(front, self.datefront)
+        try:
+            front, back = datestring.split(".")
+        except ValueError as abnormal_date:
+            self.logger.warning("Abnormal Date String: {}".format(datestring))
 
-        this_date.replace(microsecond=this_ms)
+            try:
+                this_date = datetime.datetime.strptime("%Y-%m-%d", datestring)
+            except Exception as not_secondary_date:
+                self.logger.warning("Abnormal Date String not day, returning as string: {}".format(datestring))
+                this_date = datestring
+        else:
+            this_ms = int("{}000".format(back.strip("Z")))
+            this_date = datetime.datetime.strptime(front, self.datefront)
+
+            this_date.replace(microsecond=this_ms)
 
         return this_date
 
