@@ -12,9 +12,9 @@ import abobjs
 
 class AB_Continous_Monitoring_Systems(abobjs.AB_Base):
 
-    _endpoint = "/api/v1/continous_monitoring_systems"
-    _single = ".continous_monitoring_systems[0]"
-    _name = "continous_monitoring_system"
+    _endpoint = "/api/v1/continuous_monitoring_systems"
+    _single = ".continuous_monitoring_systems[0]"
+    _name = "continuous_monitoring_system"
 
     _uid_field = None
 
